[gnome-color-manager] Correct use of calibrate/profile and replace device by instrument



commit b912453d88af597bfe987fcf741fe74db907d1f0
Author: Milan Knizek <knizek volny cz>
Date:   Sat Mar 6 20:56:06 2010 +0100

    Correct use of calibrate/profile and replace device by instrument

 src/gcm-calibrate-argyll.c |   46 ++++++++++++++++++++++----------------------
 src/gcm-calibrate-manual.c |    2 +-
 src/gcm-calibrate.c        |    6 ++--
 src/gcm-colorimeter.c      |    8 +++---
 src/gcm-prefs.c            |   18 ++++++++--------
 5 files changed, 40 insertions(+), 40 deletions(-)
---
diff --git a/src/gcm-calibrate-manual.c b/src/gcm-calibrate-manual.c
index de45e6b..486250e 100644
--- a/src/gcm-calibrate-manual.c
+++ b/src/gcm-calibrate-manual.c
@@ -215,7 +215,7 @@ gcm_calibrate_manual_setup_page (GcmCalibrateManual *calibrate, guint page)
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "label_text1"));
 		/* TRANSLATORS: message text */
 		gtk_label_set_label (GTK_LABEL(widget), _("This dialog will help calibrate your display and create a custom ICC profile. "
-							  "Display calibration will involve several steps so that an accurate profile can be obtained. "
+							  "The calibration will involve several steps so that an accurate profile can be obtained. "
 							  "It should only take a few minutes."));
 		widget = GTK_WIDGET (gtk_builder_get_object (priv->builder, "hbox_text2"));
 		gtk_widget_show (widget);
diff --git a/src/gcm-calibrate.c b/src/gcm-calibrate.c
index 309e7ae..a8a4cbf 100644
--- a/src/gcm-calibrate.c
+++ b/src/gcm-calibrate.c
@@ -374,10 +374,10 @@ gcm_calibrate_get_display_type (GcmCalibrate *calibrate, GtkWindow *window, GErr
 	if (priv->device_kind == GCM_CALIBRATE_DEVICE_KIND_PROJECTOR &&
 	    !gcm_colorimeter_supports_projector (priv->colorimeter)) {
 		/* TRANSLATORS: title, the hardware calibration device does not support projectors */
-		title = _("Could not calibrate using this colorimeter device");
+		title = _("Could not calibrate and profile using this color measuring instrument");
 
 		/* TRANSLATORS: dialog message */
-		message = _("This colorimeter device is not designed to support profiling projectors.");
+		message = _("This color measuring instrument is not designed to support calibration and profiling projectors.");
 
 		/* ask the user again */
 		gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_GENERIC, title, message);
@@ -975,7 +975,7 @@ gcm_calibrate_device (GcmCalibrate *calibrate, GtkWindow *window, GError **error
 	g_string_set_size (string, 0);
 
 	/* TRANSLATORS: dialog message, preface */
-	g_string_append_printf (string, "%s\n", _("Before calibrating the device, you have to manually capture an image of a calibrated target and save it as a TIFF image file."));
+	g_string_append_printf (string, "%s\n", _("Before profiling the device, you have to manually capture an image of a calibrated target and save it as a TIFF image file."));
 
 	/* scanner specific options */
 	if (priv->device_type == GCM_DEVICE_TYPE_ENUM_SCANNER) {
diff --git a/src/gcm-colorimeter.c b/src/gcm-colorimeter.c
index 620735f..d3edf8d 100644
--- a/src/gcm-colorimeter.c
+++ b/src/gcm-colorimeter.c
@@ -330,9 +330,9 @@ gcm_colorimeter_device_add (GcmColorimeter *colorimeter, GUdevDevice *device)
 							 GTK_MESSAGE_INFO,
 							 GTK_BUTTONS_OK,
 							 /* TRANSLATORS: this is when the device is not recognised */
-							 _("Colorimeter not recognised"));
+							 _("Measuring instrument not recognised"));
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-								  "Could not recognise attached colorimeter device '%s'. "
+								  "Could not recognise attached measuring instrument '%s'. "
 								  "It should work okay, but if you want to help the project, "
 								  "please visit %s and supply the required information.",
 								  priv->model, "http://live.gnome.org/GnomeColorManager/Help";);
@@ -352,9 +352,9 @@ gcm_colorimeter_device_add (GcmColorimeter *colorimeter, GUdevDevice *device)
 							 GTK_MESSAGE_INFO,
 							 GTK_BUTTONS_OK,
 							 /* TRANSLATORS: this is when the device is not recognised */
-							 _("Colorimeter not registered"));
+							 _("Measuring instrument not registered"));
 			gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-								  "The attached colorimeter device has not been registered in usb.ids. "
+								  "The attached measuring devicer device has not been registered in usb.ids. "
 								  "It should work okay, but if you want to help the project, "
 								  "please visit %s and supply the required information.",
 								  "http://live.gnome.org/GnomeColorManager/Help";);
diff --git a/src/gcm-prefs.c b/src/gcm-prefs.c
index f2bc07b..4412cf8 100644
--- a/src/gcm-prefs.c
+++ b/src/gcm-prefs.c
@@ -703,11 +703,11 @@ gcm_prefs_ensure_argyllcms_installed (void)
 	window = GTK_WINDOW(gtk_builder_get_object (builder, "dialog_prefs"));
 	dialog = gtk_message_dialog_new (window, GTK_DIALOG_DESTROY_WITH_PARENT, GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
 					 /* TRANSLATORS: title, usually we can tell based on the EDID data or output name */
-					 _("Install missing calibration software?"));
+					 _("Install missing calibration and profiling software?"));
 
 	string = g_string_new ("");
 	/* TRANSLATORS: dialog message saying the argyllcms is not installed */
-	g_string_append_printf (string, "%s\n", _("Calibration software is not installed on this computer."));
+	g_string_append_printf (string, "%s\n", _("Calibration and profiling software is not installed on this computer."));
 	/* TRANSLATORS: dialog message saying the color targets are not installed */
 	g_string_append_printf (string, "%s\n\n", _("These tools are required to build color profiles for devices."));
 	/* TRANSLATORS: dialog message, asking if it's okay to install it */
@@ -779,7 +779,7 @@ gcm_prefs_calibrate_cb (GtkWidget *widget, gpointer data)
 		ret = gcm_prefs_calibrate_printer (calibrate);
 		break;
 	default:
-		egg_warning ("calibration not supported for this device");
+		egg_warning ("calibration and/or profiling not supported for this device");
 		goto out;
 	}
 
@@ -851,7 +851,7 @@ gcm_prefs_calibrate_cb (GtkWidget *widget, gpointer data)
 			 /* TRANSLATORS: this is the application name for libcanberra */
 			 CA_PROP_APPLICATION_NAME, _("GNOME Color Manager"),
 			 /* TRANSLATORS: this is the sound description */
-			 CA_PROP_EVENT_DESCRIPTION, _("Calibration completed"), NULL);
+			 CA_PROP_EVENT_DESCRIPTION, _("Profiling completed"), NULL);
 out:
 	g_free (filename);
 	g_free (destination);
@@ -1105,7 +1105,7 @@ gcm_prefs_set_calibrate_button_sensitivity (void)
 	/* no device selected */
 	if (current_device == NULL) {
 		/* TRANSLATORS: this is when the button is insensitive */
-		tooltip = _("Cannot calibrate: No device is selected");
+		tooltip = _("Cannot profile: No device is selected");
 		goto out;
 	}
 
@@ -1139,7 +1139,7 @@ gcm_prefs_set_calibrate_button_sensitivity (void)
 		ret = gcm_colorimeter_get_present (colorimeter);
 		if (!ret) {
 			/* TRANSLATORS: this is when the button is insensitive */
-			tooltip = _("Cannot calibrate: The colorimeter is not plugged in");
+			tooltip = _("Cannot calibrate: The measuring instrument is not plugged in");
 			goto out;
 		}
 	} else if (type == GCM_DEVICE_TYPE_ENUM_SCANNER ||
@@ -1154,7 +1154,7 @@ gcm_prefs_set_calibrate_button_sensitivity (void)
 		ret = gcm_colorimeter_get_present (colorimeter);
 		if (!ret) {
 			/* TRANSLATORS: this is when the button is insensitive */
-			tooltip = _("Cannot calibrate: The colorimeter is not plugged in");
+			tooltip = _("Cannot profile: The measuring instrument is not plugged in");
 			goto out;
 		}
 
@@ -1162,14 +1162,14 @@ gcm_prefs_set_calibrate_button_sensitivity (void)
 		ret = gcm_colorimeter_supports_printer (colorimeter);
 		if (!ret) {
 			/* TRANSLATORS: this is when the button is insensitive */
-			tooltip = _("Cannot calibrate: The colorimeter does not support printer profiling");
+			tooltip = _("Cannot profile: The measuring instrument does not support printer profiling");
 			goto out;
 		}
 
 	} else {
 
 		/* TRANSLATORS: this is when the button is insensitive */
-		tooltip = _("Cannot calibrate this type of device");
+		tooltip = _("Cannot profile this type of device");
 	}
 out:
 	/* control the tooltip and sensitivity of the button */



[Date Prev][Date Next]   [Thread Prev][Thread Next]   [Thread Index] [Date Index] [Author Index]
diff --git a/src/gcm-calibrate-argyll.c b/src/gcm-calibrate-argyll.c
index 8ed7f64..80ef4a3 100644
--- a/src/gcm-calibrate-argyll.c
+++ b/src/gcm-calibrate-argyll.c
@@ -491,7 +491,7 @@ gcm_calibrate_argyll_display_read_chart (GcmCalibrateArgyll *calibrate_argyll, G
 	/* TRANSLATORS: title, patches are specific colours used in calibration */
 	title = _("Reading the patches");
 	/* TRANSLATORS: dialog message */
-	message = _("Reading the patches using the hardware device.");
+	message = _("Reading the patches using the color measuring instrument.");
 
 	/* push new messages into the UI */
 	gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_GENERIC, title, message);
@@ -579,7 +579,7 @@ gcm_calibrate_argyll_display_generate_patches (GcmCalibrateArgyll *calibrate_arg
 	/* TRANSLATORS: title, patches are specific colours used in calibration */
 	title = _("Generating the patches");
 	/* TRANSLATORS: dialog message */
-	message = _("Generating the patches that will be measured with the hardware device.");
+	message = _("Generating the patches that will be measured with the color instrument.");
 
 	/* push new messages into the UI */
 	gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_GENERIC, title, message);
@@ -1605,7 +1605,7 @@ gcm_calibrate_argyll_set_device_from_ti2 (GcmCalibrate *calibrate, const gchar *
 		device_ptr = device + 7;
 
 	/* set for calibration */
-	egg_debug ("setting device to '%s'", device_ptr);
+	egg_debug ("setting instrument to '%s'", device_ptr);
 	g_object_set (calibrate,
 		      "device", device_ptr,
 		      NULL);
@@ -1711,7 +1711,7 @@ gcm_calibrate_argyll_printer (GcmCalibrate *calibrate, GtkWindow *window, GError
 		title = _("Wait for the ink to dry");
 
 		/* TRANSLATORS: dialog message */
-		message = _("Please wait a few minutes for the ink to dry. Profiling damp ink will produce a poor profile and may damage your calibration device.");
+		message = _("Please wait a few minutes for the ink to dry. Profiling damp ink will produce a poor profile and may damage your color measuring instrument.");
 
 		/* push new messages into the UI */
 		gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_GENERIC, title, message);
@@ -1857,7 +1857,7 @@ gcm_calibrate_argyll_check_and_remove_alpha (GcmCalibrateArgyll *calibrate_argyl
 	title = _("Image is not suitable without conversion");
 
 	/* TRANSLATORS: dialog message */
-	string = g_string_new (_("The image supplied contains an alpha channel which the calibration tools do not understand."));
+	string = g_string_new (_("The supplied image contains an alpha channel which the profiling tools do not understand."));
 	g_string_append (string, "\n\n");
 
 	/* TRANSLATORS: dialog message */
@@ -1926,11 +1926,11 @@ gcm_calibrate_argyll_device (GcmCalibrate *calibrate, GtkWindow *window, GError
 	gcm_calibrate_dialog_set_move_window (priv->calibrate_dialog, FALSE);
 	gcm_calibrate_dialog_set_window (priv->calibrate_dialog, window);
 
-	/* TRANSLATORS: title, hardware refers to a calibration device */
-	title = _("Set up device");
+	/* TRANSLATORS: title, instrument refers to a calibration device */
+	title = _("Set up instrument");
 
 	/* TRANSLATORS: dialog message */
-	message = _("Setting up device for useâ?¦");
+	message = _("Setting up the instrument for useâ?¦");
 
 	/* push new messages into the UI */
 	gcm_calibrate_dialog_show (priv->calibrate_dialog, GCM_CALIBRATE_DIALOG_TAB_GENERIC, title, message);
@@ -2022,8 +2022,8 @@ gcm_calibrate_argyll_interaction_attach (GcmCalibrateArgyll *calibrate_argyll)
 		goto out;
 	}
 
-	/* TRANSLATORS: title, device is a hardware color calibration sensor */
-	title = _("Please attach device");
+	/* TRANSLATORS: title, instrument is a hardware color calibration sensor */
+	title = _("Please attach instrument");
 
 	/* get the image, if we have one */
 	filename = gcm_calibrate_argyll_get_colorimeter_image_attach (calibrate_argyll);
@@ -2031,10 +2031,10 @@ gcm_calibrate_argyll_interaction_attach (GcmCalibrateArgyll *calibrate_argyll)
 	/* different messages with or without image */
 	if (filename != NULL) {
 		/* TRANSLATORS: dialog message, ask user to attach device, and there's an example image */
-		message = _("Please attach the hardware device to the center of the screen on the gray square like the image below.");
+		message = _("Please attach the measuring instrument to the center of the screen on the gray square like the image below.");
 	} else {
 		/* TRANSLATORS: dialog message, ask user to attach device */
-		message = _("Please attach the hardware device to the center of the screen on the gray square.");
+		message = _("Please attach the measuring instrument to the center of the screen on the gray square.");
 	}
 
 	/* block for a response */
@@ -2077,8 +2077,8 @@ gcm_calibrate_argyll_interaction_calibrate (GcmCalibrateArgyll *calibrate_argyll
 	const gchar *filename;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
 
-	/* TRANSLATORS: title, device is a hardware color calibration sensor */
-	title = _("Please configure device");
+	/* TRANSLATORS: title, instrument is a hardware color calibration sensor */
+	title = _("Please configure instrument");
 
 	/* block for a response */
 	egg_debug ("blocking waiting for user input: %s", title);
@@ -2088,10 +2088,10 @@ gcm_calibrate_argyll_interaction_calibrate (GcmCalibrateArgyll *calibrate_argyll
 
 	if (filename != NULL) {
 		/* TRANSLATORS: this is when the user has to change a setting on the sensor, and we're showing a picture */
-		message = _("Please set the device to calibration mode like the image below.");
+		message = _("Please set the measuring instrument to calibration mode like the image below.");
 	} else {
 		/* TRANSLATORS: this is when the user has to change a setting on the sensor */
-		message = _("Please set the device to calibration mode.");
+		message = _("Please set the measuring instrument to calibration mode.");
 	}
 
 	/* push new messages into the UI */
@@ -2129,8 +2129,8 @@ gcm_calibrate_argyll_interaction_surface (GcmCalibrateArgyll *calibrate_argyll)
 	const gchar *filename;
 	GcmCalibrateArgyllPrivate *priv = calibrate_argyll->priv;
 
-	/* TRANSLATORS: title, device is a hardware color calibration sensor */
-	title = _("Please configure device");
+	/* TRANSLATORS: title, instrument is a hardware color calibration sensor */
+	title = _("Please configure instrument");
 
 	/* block for a response */
 	egg_debug ("blocking waiting for user input: %s", title);
@@ -2140,10 +2140,10 @@ gcm_calibrate_argyll_interaction_surface (GcmCalibrateArgyll *calibrate_argyll)
 
 	if (filename != NULL) {
 		/* TRANSLATORS: this is when the user has to change a setting on the sensor, and we're showing a picture */
-		message = _("Please set the device to screen mode like the image below, and ensure it is attached to the screen.");
+		message = _("Please set the measuring instrument to screen mode like the image below, and ensure it is attached to the screen.");
 	} else {
 		/* TRANSLATORS: this is when the user has to change a setting on the sensor */
-		message = _("Please set the device to screen mode, and ensure it is attached to the screen.");
+		message = _("Please set the measuring instrument to screen mode, and ensure it is attached to the screen.");
 	}
 
 	/* push new messages into the UI */
@@ -2266,17 +2266,17 @@ gcm_calibrate_argyll_process_output_cmd (GcmCalibrateArgyll *calibrate_argyll, c
 
 		if (g_strstr_len (line, -1, "No PLD firmware pattern is available") != NULL) {
 			/* TRANSLATORS: message, no firmware is available */
-			message = _("No firmware is installed for this device.");
+			message = _("No firmware is installed for this instrument.");
 		} else if (g_strstr_len (line, -1, "Pattern match wasn't good enough") != NULL) {
 			/* TRANSLATORS: message, the image wasn't good enough */
 			message = _("The pattern match wasn't good enough. Ensure you have the correct type of target selected.");
 		} else if (g_strstr_len (line, -1, "Aprox. fwd matrix unexpectedly singular") != NULL ||
 			   g_strstr_len (line, -1, "Inverting aprox. fwd matrix failed") != NULL) {
 			/* TRANSLATORS: message, the sensor got no readings */
-			message = _("The colorimeter got no valid readings. Please ensure the aperture is fully open.");
+			message = _("The measuring instrument got no valid readings. Please ensure the aperture is fully open.");
 		} else if (g_strstr_len (line, -1, "Device or resource busy") != NULL) {
 			/* TRANSLATORS: message, the colorimeter has got confused */
-			message = _("The colorimeter device is busy and is not starting up. Please remove the USB plug and re-insert before trying to use this device.");
+			message = _("The measuring instrument is busy and is not starting up. Please remove the USB plug and re-insert before trying to use this device.");
 		} else {
 			message = found + 8;
 		}